@@ -1,9 +1,12 @@
 import sys
 import warnings
-import pkg_resources
+try:
+    import importlib.metadata as importlib_metadata
+except ImportError:
+    import importlib_metadata
 
 try:
-    __version__ = pkg_resources.require('python-dispatch')[0].version
+    __version__ = importlib_metadata.version('python-dispatch')
 except: # pragma: no cover
     __version__ = 'unknown'
 
@@ -12,5 +15,5 @@ if sys.version_info < (3, 6): # pragma: no cover
                   'After version 0.1.x, `python-dispatch` will only support Python 3.6 or greater.',
                   UserWarning)
 
-from pydispatch.dispatch import Dispatcher
+from pydispatch.dispatch import Dispatcher, Event
 from pydispatch.properties import *
